@@ -17,9 +17,12 @@
 #' For this reason, newly created credentials can not immediately be used by `sen2r`, 
 #' and password edits on old credentials are not immediately recognised.
 #' @author Luigi Ranghetti, phD (2019) \email{luigi@@ranghetti.info}
+#' @references L. Ranghetti, M. Boschetti, F. Nutini, L. Busetto (2020).
+#'  "sen2r": An R toolbox for automatically downloading and preprocessing 
+#'  Sentinel-2 satellite data. _Computers & Geosciences_, 139, 104473. DOI: 
+#'  \href{https://doi.org/10.1016/j.cageo.2020.104473}{10.1016/j.cageo.2020.104473}, 
+#'  URL: \url{http://sen2r.ranghetti.info/}.
 #' @note License: GPL 3.0
-#' @importFrom shiny a actionButton icon modalButton modalDialog passwordInput tagList textInput
-#' @importFrom shinyFiles shinyFileSave
 #' 
 #' @examples
 #'   check_scihub_login("user", "user")
@@ -161,6 +164,25 @@ write_scihub_login <- function(username, password,
 
 # write dialog content
 .scihub_modal <- function() { #nocov start
+  
+  # Define internal functions as aliases of shiny* - leaflet* ones,
+  # so to avoid using "shiny::" every time
+  a <- shiny::a
+  actionButton <- shiny::actionButton
+  actionLink <- shiny::actionLink
+  checkboxInput <- shiny::checkboxInput
+  conditionalPanel <- shiny::conditionalPanel
+  div <- shiny::div
+  HTML <- shiny::HTML
+  icon <- shiny::icon
+  modalButton <- shiny::modalButton
+  modalDialog <- shiny::modalDialog
+  passwordInput <- shiny::passwordInput
+  shinySaveButton <- shinyFiles::shinySaveButton
+  span <- shiny::span
+  tagList <- shiny::tagList
+  textInput <- shiny::textInput
+  
   # read scihub user/password
   apihub_path <- file.path(dirname(attr(load_binpaths(), "path")), "apihub.txt")
   apihub <- if (file.exists(apihub_path)) {
