@@ -27,6 +27,11 @@
 #' @importFrom sf gdal_crs st_crs
 #' @export
 #' @author Luigi Ranghetti, phD (2019) \email{luigi@@ranghetti.info}
+#' @references L. Ranghetti, M. Boschetti, F. Nutini, L. Busetto (2020).
+#'  "sen2r": An R toolbox for automatically downloading and preprocessing 
+#'  Sentinel-2 satellite data. _Computers & Geosciences_, 139, 104473. DOI: 
+#'  \href{https://doi.org/10.1016/j.cageo.2020.104473}{10.1016/j.cageo.2020.104473}, 
+#'  URL: \url{http://sen2r.ranghetti.info/}.
 #' @note License: GPL 3.0
 #' @examples 
 #' ## CRS from EPSG
@@ -114,23 +119,10 @@ st_crs2.character <- function(x, ...) {
   ## case 2: PROJ.4
   if (grepl("^\\+[a-z]+\\=", x)) {
     # x: PROJ.4 -> character PROJ.4 with warning
-    gdal_version <- tryCatch(
-      package_version(gsub(
-        "^.*GDAL ([0-9\\.]+)[^0-9].*$", "\\1",
-        system(paste0(load_binpaths("gdal")$gdalinfo," --version"), intern = TRUE)
-      )), # checking GDAL >=3 instead than PROJ >= 6 for simplicity
-      error = function(e) {3} # in case of errors, return the warning
-    )
     print_message(
       type = "warning",
       "Using PROJ.4 strings is deprecated with PROJ >= 6 ",
-      "(see https://www.r-spatial.org/r/2020/03/17/wkt.html)",
-      if (gdal_version >= 3) {
-        paste0(
-          "and with PROJ >= 6 ",
-          "(see http://rgdal.r-forge.r-project.org/articles/PROJ6_GDAL3.html)."
-        )
-      } else {"."}
+      "(see https://www.r-spatial.org/r/2020/03/17/wkt.html)."
     )
     return(sf::st_crs(x, ...))
   }
