@@ -2,15 +2,13 @@ context("Test s2_list() and safe_getMetadata(info = 'nameinfo')")
 testthat::skip_on_cran()
 # testthat::skip_on_travis()
 
-write_scihub_login("user", "user", apihub_path <- tempfile())
-
 testthat::test_that(
   "Tests on s2_list - Single tile, single orbit, no pos", {
     s2_list_test <- s2_list(
       tile = "32TNR",
       time_interval = as.Date(c("2017-05-01", "2017-05-31")),
       orbit = "065",
-      apihub = apihub_path
+      apihub = tests_apihub_path
     )
     testthat::expect_is(s2_list_test, "safelist")
     s2_dt_test <- as(s2_list_test, "data.table")
@@ -46,7 +44,7 @@ testthat::test_that(
       tile = "32TNR",
       time_interval = as.Date(c("2017-05-01", "2017-05-31")),
       availability = "check",
-      apihub = apihub_path
+      apihub = tests_apihub_path
     )
     testthat::expect_is(s2_list_test, "safelist")
     s2_sf_test <- as(s2_list_test, "sf")
@@ -73,7 +71,7 @@ testthat::test_that(
       tile = c("32TNR", "32TMR"),
       time_interval = as.Date(c("2017-05-01", "2017-05-31")),
       availability = "check",
-      apihub = apihub_path
+      apihub = tests_apihub_path
     ))
     testthat::expect_equal(nrow(s2_list_test), 11)
     testthat::expect_equal(unique(s2_list_test$id_tile), c("32TNR", "32TMR"))
@@ -111,7 +109,7 @@ testthat::test_that(
       time_interval = as.Date(c("2017-05-01", "2017-05-31")),
       orbit = "065",
       availability ="online",
-      apihub = apihub_path
+      apihub = tests_apihub_path
     )
     testthat::expect_lte(length(s2_list_test), 3)
   }
@@ -126,7 +124,7 @@ testthat::test_that(
       time_interval = as.Date(c("2017-05-01", "2017-05-31")),
       orbit = "065",
       availability = "lta",
-      apihub = apihub_path
+      apihub = tests_apihub_path
     )
     testthat::expect_lte(length(s2_list_test), 3)
   }
@@ -141,7 +139,7 @@ testthat::test_that(
       time_interval = as.Date(c("2016-05-01", "2016-05-31")),
       orbit = "065",
       max_cloud = 50,
-      apihub = apihub_path
+      apihub = tests_apihub_path
     )
     testthat::expect_equal(length(s2_list_test), 1)
   }
@@ -155,7 +153,7 @@ testthat::test_that(
       spatial_extent = pos,
       tile = "32TNR",
       time_interval = time_window,
-      apihub = apihub_path
+      apihub = tests_apihub_path
     )
     testthat::expect_equal(length(s2_list_test), 6)
   }
@@ -171,7 +169,7 @@ testthat::test_that(
       s2_list(
         spatial_extent = pos, 
         time_interval = time_window, 
-        apihub = apihub_path
+        apihub = tests_apihub_path
       ), 
       "data.frame"
     )
@@ -183,7 +181,7 @@ testthat::test_that(
       s2_list(
         spatial_extent = pos, 
         time_interval = time_window,
-        apihub = apihub_path
+        apihub = tests_apihub_path
       ),
       "data.frame"
     )
@@ -201,7 +199,7 @@ testthat::test_that(
     s2_list_test <- s2_list(
       spatial_extent = pos,
       time_interval = time_window,
-      apihub = apihub_path
+      apihub = tests_apihub_path
     )
     testthat::expect_equal(length(s2_list_test), 69)
   }
@@ -214,7 +212,7 @@ testthat::test_that(
     s2_list_test <- s2_list(
       spatial_extent = pos,
       time_interval = time_window,
-      apihub = apihub_path
+      apihub = tests_apihub_path
     )
     testthat::expect_equal(length(s2_list_test), 182)
   }
@@ -227,7 +225,7 @@ testthat::test_that(
       spatial_extent = pos,
       tile = "32TNR",
       time_interval = as.Date(c("2016-05-01", "2016-05-01")),
-      apihub = apihub_path
+      apihub = tests_apihub_path
     )
     testthat::expect_equal(length(s2_list_test), 0)
     testthat::expect_equal(
@@ -251,7 +249,7 @@ testthat::test_that(
       time_interval = as.Date(c("2016-05-01", "2017-08-01")),
       time_period = "seasonal",
       orbit = "065",
-      apihub = apihub_path
+      apihub = tests_apihub_path
     )
     testthat::expect_equal(length(s2_list_test), 22)
   }
@@ -266,7 +264,7 @@ testthat::test_that(
       time_interval = as.Date(c("2017-05-01", "2017-06-30")),
       time_period = "seasonal",
       orbit = "065",
-      apihub = apihub_path
+      apihub = tests_apihub_path
     )
     testthat::expect_equal(length(s2_list_test), 6)
   }
@@ -282,7 +280,7 @@ testthat::test_that(
       time_interval = as.Date(c("2017-05-01", "2017-06-30")),
       time_period = "seasonal",
       orbit = "065",
-      apihub = apihub_path
+      apihub = tests_apihub_path
     )
     testthat::expect_equal(length(s2_list_test), 6)
   }
@@ -298,7 +296,7 @@ testthat::test_that(
       time_interval = as.Date(c("2016-05-01", "2017-06-30")),
       time_period = "seasonal",
       orbit = "065",
-      apihub = apihub_path
+      apihub = tests_apihub_path
     ))
     testthat::expect_equal(length(s2_list_test$level), 11)
     testthat::expect_equal(unique(s2_list_test$level), c("1C" , "2Ap"))
@@ -315,7 +313,7 @@ testthat::test_that(
       time_interval = as.Date(c("2016-05-01", "2017-06-30")),
       time_period = "seasonal",
       orbit = "065",
-      apihub = apihub_path
+      apihub = tests_apihub_path
     ))
     testthat::expect_equal(length(s2_list_test$level), 11)
     testthat::expect_equal(unique(s2_list_test$level), c("1C"))
@@ -336,7 +334,7 @@ testthat::test_that(
       s2_list(
         spatial_extent = "pos",
         time_interval = as.Date(c("2017-05-01", "2017-06-30")),
-        apihub = apihub_path
+        apihub = tests_apihub_path
       ),
       regexp = gsub(
         " ", "[ \n]",
@@ -349,7 +347,7 @@ testthat::test_that(
       s2_list(
         spatial_extent = pos,
         time_interval = c("2017-05-XX", "2017-06-30"),
-        apihub = apihub_path
+        apihub = tests_apihub_path
       ),
       regexp = gsub(
         " ", "[ \n]",
@@ -363,7 +361,7 @@ testthat::test_that(
         spatial_extent = pos,
         time_interval = c("2017-05-01", "2017-06-30"),
         availability = "offline",
-        apihub = apihub_path
+        apihub = tests_apihub_path
       ),
       regexp = gsub(
         " ", "[ \n]",
