@@ -2,9 +2,6 @@ context("Test compute spectral indices - main function")
 testthat::skip_on_cran()
 # testthat::skip_on_travis() # because required SAFE do not exists
 
-safe_dir <- file.path(dirname(attr(load_binpaths(), "path")), "safe")
-dir.create(safe_dir, showWarnings = FALSE)
-
 testthat::test_that(
   "Tests on indices computation, on unrequired BOA, with clip ", {
     
@@ -27,7 +24,8 @@ testthat::test_that(
       mask_type = NA,
       path_out = outdir_11,
       path_l2a = safe_dir,
-      parallel = FALSE
+      parallel = FALSE,
+      apihub = tests_apihub_path
     )
     testthat::expect_true(all(file.exists(exp_outpath_11)))
     
